Merge from Chromium at DEPS revision 225410

This commit was generated by merge_to_master.py.

Change-Id: Ifa1539ca216abb163295ee7a77f81bb67f52e178
diff --git a/ash/ash_switches.cc b/ash/ash_switches.cc
index bb0fe87..c64b090 100644
--- a/ash/ash_switches.cc
+++ b/ash/ash_switches.cc
@@ -118,12 +118,18 @@
 // Enable memory monitoring.
 const char kAshEnableMemoryMonitor[] = "ash-enable-memory-monitor";
 #endif
-
+#if defined(OS_CHROMEOS)
+// Enable the shelf menu for multi profile usage.
+const char kAshEnableMultiProfileShelfMenu[] = "ash-enable-multi-profile-shelf";
+#endif
 // Enables the Oak tree viewer.
 const char kAshEnableOak[] = "ash-enable-oak";
 
-// Disables overview mode for window switching.
-const char kAshDisableOverviewMode[] = "ash-disable-overview-mode";
+// Enables overview mode for window switching.
+const char kAshEnableOverviewMode[] = "ash-enable-overview-mode";
+
+// Enables software based mirroring.
+const char kAshEnableSoftwareMirroring[] = "ash-enable-software-mirroring";
 
 // Enables "sticky" edges instead of "snap-to-edge"
 const char kAshEnableStickyEdges[] = "ash-enable-sticky-edges";
@@ -217,6 +223,16 @@
       HasSwitch(kHideShelfAlignmentMenu);
 }
 
+// Returns true if the MultiProfile shelf menu should be shown.
+bool ShowMultiProfileShelfMenu() {
+#if defined(OS_CHROMEOS)
+  return CommandLine::ForCurrentProcess()->
+      HasSwitch(kAshEnableMultiProfileShelfMenu);
+#else
+  return false;
+#endif
+}
+
 #if defined(OS_CHROMEOS)
 bool ShowAudioDeviceMenu() {
   return !CommandLine::ForCurrentProcess()->